package org.datanucleus.management.platform;

import java.lang.management.ManagementFactory;

import javax.management.MBeanServer;
import javax.management.ObjectName;

import org.datanucleus.exceptions.NucleusException;
import org.datanucleus.management.ManagementServer;
import org.datanucleus.util.NucleusLogger;

public class PlatformManagementServer implements ManagementServer
{
    MBeanServer mbeanServer;

    public void start()
    {
        if( NucleusLogger.MANAGEMENT.isDebugEnabled() )
        {
            NucleusLogger.MANAGEMENT.debug("Starting ManagementServer");
        }

        mbeanServer = ManagementFactory.getPlatformMBeanServer();
    }

    public void stop()
    {
        if( NucleusLogger.MANAGEMENT.isDebugEnabled() )
        {
            NucleusLogger.MANAGEMENT.debug("Stopping ManagementServer");
        }
        mbeanServer = null;
    }

    /**
     * Register a MBean into the MBeanServer
     * @param mbean the MBean instance
     * @param name the mbean name
     */
    public void registerMBean(Object mbean, String name)
    {
        try
        {
            ObjectName objName = new ObjectName(name);
            mbeanServer.registerMBean(mbean, objName);
        }
        catch (Exception e)
        {
            throw new NucleusException(e.getMessage(),e);
        }
    }
    
    /**
     * Unregister a MBean from the MBeanServer
     * @param name the mbean name
     */
    public void unregisterMBean(String name)
    {
        try
        {
            ObjectName objName = new ObjectName(name);
            mbeanServer.unregisterMBean(objName);
        }
        catch (Exception e)
        {
            throw new NucleusException(e.getMessage(),e);
        }
    }

}